@@ -1,8 +1,8 @@
 import uuid
 from types import GeneratorType
-from typing import Tuple, List, Type, Dict
+from typing import Tuple, List, Type, Dict, Union
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 from pypads import logger
 from pypads.app.env import InjectionLoggerEnv
 from pypads.app.injections.base_logger import TrackedObject
@@ -10,6 +10,9 @@ from pypads.app.injections.injection import OriginalExecutor, MultiInjectionLogg
 from pypads.importext.mappings import LibSelector
 from pypads.importext.versioning import all_libs
 from pypads.model.logger_output import TrackedObjectModel, OutputModel
+from pypads.model.models import IdReference
+from pypads_onto.arguments import ontology_uri
+# from pypads_onto.model.ontology import EmbeddedOntologyModel
 
 from pypads_padre.concepts.util import _tolist
 
@@ -19,25 +22,29 @@ def splitter_output(result, fn):
     try:
         if isinstance(result, Tuple):
             if "sklearn" in fn.__module__:
-                return result[0].tolist(), result[1].tolist(), None, None
-            elif "default_splitter" in fn.__name__:
-                return result[1], result[2], result[3], result[0]
+                return result[0].tolist(), result[1].tolist(), None
+            elif "default_split" in fn.__name__:
+                return result
             else:
                 if len(result) < 4:
-                    return _tolist(result[0]), _tolist(result[1]), _tolist(result[3]), None
+                    result_ = [_tolist(r) for r in result]
+                    return tuple(result_ + [None]*(3-len(result_)))
+                else:
+                    return None, None, None
         else:
             if "torch" in fn.__module__:
                 if hasattr(fn, "_dataset"):
-                    if fn._dataset.train:
-                        return result.tolist(), None, None, None
-                    else:
-                        return None, result.tolist(), None, None
-                return result.tolist(), None, None, None
+                    if hasattr(fn._dataset,"train"):
+                        if fn._dataset.train:
+                            return _tolist(result), None, None
+                        else:
+                            return None, _tolist(result), None
+                return _tolist(result), None, None
             else:
-                return None, None, None, None
+                return None, None, None
     except Exception as e:
         logger.warning("Split tracking ommitted due to exception {}".format(str(e)))
-        return None, None, None, None
+        return None, None, None
 
 
 class SplitTO(TrackedObject):
@@ -45,14 +52,26 @@ class SplitTO(TrackedObject):
     Tracking Object class for splits of your tracked dataset. Splits are defined
     """
 
-    name = "Splits"
-
     class SplitModel(TrackedObjectModel):
         """
         Model defining the values of a split for the tracked object.
         """
-
         class Split(BaseModel):
+            context: Union[List[str], str, dict] = Field(alias="@context", default={
+                "train_set": {
+                    "@id": f"{ontology_uri}has_trainSet",
+                    "@type": "rdf:XMLLiteral"
+                },
+                "test_set": {
+                    "@id": f"{ontology_uri}has_testSet",
+                    "@type": "rdf:xsd:list"
+                },
+                "validation_set": {
+                    "@id": f"{ontology_uri}has_valSet",
+                    "@type": "rdf:xsd:list"
+                }
+            })
+            category = "Split"
             train_set: List = []
             test_set: List = []
             validation_set: List = []
@@ -61,8 +80,7 @@ class SplitTO(TrackedObject):
                 orm_mode = True
                 arbitrary_types_allowed = True
 
-        # splits: List[Split] = []
-        category: str = "Split"
+        category: str = "Splits"
         name: str = "Tracked Splits"
         description = "This object holds the tracked splits in your workflow as " \
                       "a dict of 'split_id': {'train_set': [...], 'test_set': [...], 'validation_set': [...]}"
@@ -82,8 +100,8 @@ class SplitTO(TrackedObject):
             test_set = []
         if train_set is None:
             train_set = []
-        split = self.SplitModel.Split(train_set=train_set, test_set=test_set,
-                                      validation_set=val_set)
+        split = self.SplitModel.Split(train_set=_tolist(train_set), test_set=_tolist(test_set),
+                                      validation_set=_tolist(val_set))
         self.splits.update({str(split_id): split})
 
 
@@ -91,7 +109,7 @@ class SplitsOutput(OutputModel):
     """
     Output of the Split Logger.
     """
-    splits: str = None  # reference to the splits TO
+    splits: IdReference = None  # reference to the splits TO
 
 
 class SplitILF(MultiInjectionLogger):
@@ -118,7 +136,7 @@ class SplitILF(MultiInjectionLogger):
         logger_call.output = output.store()
 
     def __call_wrapped__(self, ctx, *args, _pypads_env: InjectionLoggerEnv, _logger_call, _logger_output, _args,
-                         _kwargs):
+                         _kwargs, **kwargs):
         """
 
         :param ctx:
@@ -130,7 +148,6 @@ class SplitILF(MultiInjectionLogger):
 
         from pypads.app.pypads import get_current_pads
         pads = get_current_pads()
-        pads.cache.run_add("split_tracker", id(self))
         _return, time = OriginalExecutor(fn=_pypads_env.callback)(*_args, **_kwargs)
 
         if isinstance(_return, GeneratorType):
@@ -146,12 +163,9 @@ class SplitILF(MultiInjectionLogger):
                 for r in items:
                     split_id = uuid.uuid4()
                     pads.cache.run_add("current_split", split_id)
-                    train, test, val, num = splitter_output(r, fn=_pypads_env.callback)
+                    train, test, val = splitter_output(r, fn=_pypads_env.callback)
                     splits.add_split(split_id, train, test, val)
                     _logger_output.splits = splits
-                    # # splits.store(output, "splits")
-                    # pads.cache.run_add(pads.cache.run_get("split_tracker"),
-                    #                    {'call': call, 'output': output, 'TO': splits})
                     yield r
         else:
             def generator():
@@ -161,7 +175,7 @@ class SplitILF(MultiInjectionLogger):
                     splits = SplitTO(parent=_logger_output)
                 else:
                     splits = _logger_output.splits
-                train, test, val, num = splitter_output(_return, fn=_pypads_env.callback)
+                train, test, val = splitter_output(_return, fn=_pypads_env.callback)
                 split_id = uuid.uuid4()
                 pads.cache.run_add("current_split", split_id)
                 splits.add_split(split_id, train, test, val)
@@ -179,11 +193,16 @@ class SplitILFTorch(MultiInjectionLogger):
             Hook this logger to the splitting functionality of pytorch dataloader (e.g: DataLoader._next_index)
     """
     name = "SplitTorch Logger"
-    category = "SplitLogger"
+    category = "TorchSplitLogger"
 
     supported_libraries = {LibSelector(name="torch", constraint="*", specificity=1)}
 
-    def get_model_cls(cls) -> Type[BaseModel]:
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.identity = SplitILF.__name__
+
+    @classmethod
+    def output_schema_class(cls) -> Type[BaseModel]:
         return SplitsOutput
 
     def _handle_error(self, *args, ctx, _pypads_env, error, **kwargs):
@@ -204,13 +223,12 @@ class SplitILFTorch(MultiInjectionLogger):
                  **kwargs):
         from pypads.app.pypads import get_current_pads
         pads = get_current_pads()
-        pads.cache.run_add("split_tracker", id(self))
         if _logger_output.splits is None:
             splits = SplitTO(parent=_logger_output)
         else:
             splits = _logger_output.splits
         logger.info("Detected splitting, Tracking splits started...")
-        train, test, val, num = splitter_output(_pypads_result, fn=ctx)
+        train, test, val = splitter_output(_pypads_result, fn=ctx)
         split_id = uuid.uuid4()
         pads.cache.run_add("current_split", split_id)
         splits.add_split(split_id, train, test, val)
